.. Please when editing this file make sure to keep it matching the
   docs in ../configuration.rst:reference_to_examples

sphinx_gallery.backreferences
=============================

.. automodule:: sphinx_gallery.backreferences

   
   

   Functions
   ---------

   

   .. autofunction:: identify_names

   .. _sphx_glr_backref_sphinx_gallery.backreferences.identify_names:

   .. minigallery:: sphinx_gallery.backreferences.identify_names
       :add-heading:
   
   

   
   

   Classes
   -------

   
   .. autoclass:: DummyClass
      :members:

   .. _sphx_glr_backref_sphinx_gallery.backreferences.DummyClass:

   .. minigallery:: sphinx_gallery.backreferences.DummyClass
       :add-heading:
   .. autoclass:: NameFinder
      :members:

   .. _sphx_glr_backref_sphinx_gallery.backreferences.NameFinder:

   .. minigallery:: sphinx_gallery.backreferences.NameFinder
       :add-heading:
   
   

   
   
   